ContainerInfos class

Basic infos of a Container.

Implementers

Constructors

ContainerInfos(String containerName, String? id, String? image, List<String>? ports, String? containerNetwork, String? containerHostname, [List<String>? args])

Properties

args ↔ List<String>?
getter/setter pair
containerHostname → String?
final
containerName → String
final
containerNetwork → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
image → String?
final
ports → List<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited