DockerCommanderConsole class

Constructors

DockerCommanderConsole(DockerCommander dockerCommander, ParameterProvider parameterProvider, ConsoleOutput consoleOutput)

Properties

consoleOutput → ConsoleOutput
final
dockerCommander → DockerCommander
final
filterEnvironmentProperties → List<FilterEnvironmentProperties>
final
filterPorts → List<FilterPortsProperties>
final
filterVolumesProperties → List<FilterEnvironmentProperties>
final
hashCode → int
The hash code for this object.
no setterinherited
parameterProvider → ParameterProvider
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

executeCommand(String line) → Future<bool>
executeConsoleCMD(ConsoleCMD cmd) → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showHelp() → Future<void>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited