DockerCommanderFormula class

A docker_commander Formula:

Properties

hashCode → int
The hash code for this object.
no setterinherited
language → String
no setter
overwriteFunctionCMD ↔ bool Function(String cmdLine, ConsoleCMD cmd)?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ DockerCommanderFormulaSource
The formula source.
getter/setter pair

Methods

exec(String functionName, [List? arguments, Map<String, dynamic>? fields]) → Future
Executes a formula function.
getFields() → Future<Map<String, Object>>
getFormulaClassName() → Future<String>
Returns the formula class name.
getFormulaName() → Future<String>
Returns the formula name, calling getName.
getFormulaVersion() → Future<String>
Returns the formula version, calling getVersion.
getFunctions() → Future<List<String>>
getVM() → Future<ApolloVM?>
Returns a ApolloVM loaded with the formula code.
install([List parameters = const []]) → Future<bool>
Install this formula, calling install().
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
overwriteField(String fieldName, dynamic value) → void
restart() → Future<bool>
Restarts this formula, calling stop() than start().
run(String command, List parameters, {Map<String, dynamic>? fields}) → Future<ASTValue?>
Runs a formula command with parameters.
setup({DockerCommander? dockerCommander, DockerCommanderConsole? dockerCommanderConsole}) → void
Setups this formula to be used.
start() → Future<bool>
Starts this formula, calling start().
stop() → Future<bool>
Stops this formula, calling stop().
toString() → String
A string representation of this object.
inherited
uninstall([List parameters = const []]) → Future<bool>
Uninstall this formula, calling uninstall().

Operators

operator ==(Object other) → bool
The equality operator.
inherited