DockerCommanderFormulaRepositoryStandard class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
parent ↔ DockerCommanderFormulaRepository?
The optional parent DockerCommanderFormulaRepository of this instance.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFormula(String formulaName) → Future<DockerCommanderFormula?>
Returns a DockerCommanderFormula for formulaName.
inherited
getFormulaSource(String formulaName) → Future<DockerCommanderFormulaSource?>
Returns a DockerCommanderFormulaSource for formulaName.
inherited
getFormulasSourcesTable() → Future<Map<String, DockerCommanderFormulaSource>>
inherited
listFormulasNames() → FutureOr<List<String>>
Lists the formulas names in this repository.
inherited
listFormulasSources() → List<DockerCommanderFormulaSource>
Lists the DockerCommanderFormulaSource of this repository.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited