DockerProcess class abstract

Implementers

Constructors

DockerProcess(DockerHost dockerHost, int instanceID, String containerName)

Properties

containerName → String
The name of the associated container.
final
dockerHost → DockerHost
DockerHost where this container is running.
final
exitCode → int?
The exist code, returned by waitExit, or null if still running.
no setter
exitElapsedTime → Duration?
If exitCode is defined, returns the elapsed time from exitTime.
no setter
exitTime → DateTime?
Returns the time of exit. Computed when exitCode is set.
no setter
hashCode → int
The hash code for this object.
no setterinherited
instanceID → int
The internal instanceID in DockerCommander.
final
isFinished → bool
Returns true if exitCode is defined (process exited).
no setter
isReady → bool
Returns true if this container is started and ready.
no setter
isRunning → bool
Returns true if this containers is running.
no setter
outputReadyType → OutputReadyType?
The ready output behavior.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stderr → Output?
The STDERR of this container.
no setter
stdout → Output?
The STDOUT of this container.
no setter

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setupOutputReadyType(OutputReadyType outputReadyType) → void
setupStderr(OutputStream outputStream) → void
setupStdout(OutputStream outputStream) → void
toString() → String
A string representation of this object.
override
waitExit({int? desiredExitCode, Duration? timeout}) → Future<int?>
Waits this container to naturally exit.
waitExitAndConfirm(int desiredExitCode) → Future<bool>
Waits this container to naturally exit.
waitReady() → Future<bool>
Waits this container to start and be ready.
waitStderr({int? desiredExitCode}) → Future<Output?>
Calls waitExit and returns stderr
waitStdout({int? desiredExitCode}) → Future<Output?>
Calls waitExit and returns stdout

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultOutputLimit → int
final

Static Methods

incrementInstanceID() → int