MySQLContainer class
Methods
appendFileContent (String filePath , String content , {bool sudo = false })
→ Future <bool >
Append to the file filePath with content, inside this container.
inherited
catLogs ({bool stderr = false , Pattern ? waitDataMatcher , Duration ? waitDataTimeout , bool waitExit = false , int ? desiredExitCode , bool follow = false })
→ Future <String ? >
Returns this Container logs as String .
inherited
copyFileFromContainer (String containerFilePath , String hostFilePath )
→ Future <bool >
Copy a file inside this container, with path containerFilePath,
to the host machine, at hostFilePath.
inherited
copyFileToContainer (String hostFilePath , String containerFilePath )
→ Future <bool >
Copy a host file, at hostFilePath, inside this container,
with internal file path containerFilePath.
inherited
exec (String command , List <String > args , {bool outputAsLines = true , int ? outputLimit , OutputReadyFunction ? stdoutReadyFunction , OutputReadyFunction ? stderrReadyFunction , OutputReadyType ? outputReadyType })
→ Future <DockerProcess ? > ?
Executes a command inside this container with args
(if isRunning or returns null).
inherited
execAndWaitExit (String command , List <String > args )
→ Future <int ? >
Calls exec than waitExit .
inherited
execAndWaitStderr (String command , List <String > args , {int ? desiredExitCode })
→ Future <Output ? >
Calls exec than waitStderr.
inherited
execAndWaitStderrAsString (String command , List <String > args , {bool trim = false , int ? desiredExitCode })
→ Future <String ? >
Calls execAndWaitStderrAsString and returns Output.asString .
inherited
execAndWaitStdout (String command , List <String > args , {int ? desiredExitCode })
→ Future <Output ? >
Calls exec than waitStdout.
inherited
execAndWaitStdoutAsString (String command , List <String > args , {bool trim = false , int ? desiredExitCode })
→ Future <String ? >
Calls execAndWaitStdoutAsString and returns Output.asString .
inherited
execCat (String filePath , {bool trim = false })
→ Future <String ? >
Call POSIX cat command.
Calls exec with command cat and args filePath.
Returns the executable path for filePath.
inherited
execShell (String script , {bool sudo = false })
→ Future <DockerProcess ? >
Executes a shell script. Tries to use bash or sh.
Note that script should be inline, without line breaks (\n).
inherited
execWhich (String commandName , {bool ignoreCache = false , String ? def })
→ Future <String ? >
Call POSIX which command.
Calls exec with command which and args commandName.
Caches response than returns the executable path for commandName.
inherited
healthStatus ()
→ Future <String ? >
Returns the health status of this container (starting, healthy or
unhealthy), or null if it has no health check.
inherited
hostPortFor (int containerPort )
→ int ?
The host port mapped to containerPort, or null if not published.
inherited
mysqlCMD (String cmdInline )
→ Future <String ? >
Runs a mysql command. Note that cmdInline should be a inline String , without line-breaks (\n).
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openLogs (String containerNameOrID )
→ Future <DockerProcess ? >
Opens this Container logs:
inherited
putFileContent (String filePath , String content , {bool sudo = false , bool append = false })
→ Future <bool >
Save the file filePath with content, inside this container.
inherited
runSQL (String sqlInline )
→ Future <String ? >
Runs a SQL. Note that sqlInline should be a inline String , without line-breaks (\n).
stop ({Duration ? timeout })
→ Future <bool >
Stops this container.
inherited
toString ()
→ String
A string representation of this object.
inherited
waitExit ()
→ Future <int ? >
Waits container to exit. Returns the process exit code.
inherited
waitHealthy ({Duration ? timeout , Duration interval = const Duration(milliseconds: 250) })
→ Future <bool >
Waits for this container's health check to report healthy.
Returns false if it reports unhealthy, has no health check, or
timeout (default: 1 minute) passes.
inherited
waitReady ()
→ Future <bool >
Waits for the container, ensuring that is started.
inherited