MySQLContainerConfig class

MySQL pre-configured container.

Inheritance

Constructors

MySQLContainerConfig({String? version = 'latest', String dbUser = 'myuser', String dbPassword = 'mypass', String dbName = 'mydb', int? hostPort, bool forceNativePasswordAuthentication = false, List<String>? daemonArguments})

Properties

cleanContainer → bool?
finalinherited
containerPorts → List<int>?
finalinherited
dbName ↔ String
MySQL DB name.
getter/setter pair
dbPassword ↔ String
MySQL DB password.
getter/setter pair
dbUser ↔ String
MySQL DB username.
getter/setter pair
environment → Map<String, String>?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hostname → String?
finalinherited
hostPorts → List<int>?
finalinherited
image → String
finalinherited
imageArgs → List<String>?
finalinherited
name → String?
finalinherited
network → String?
finalinherited
outputAsLines → bool
finalinherited
outputLimit → int?
finalinherited
ports → List<String>?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stderrReadyFunction → OutputReadyFunction?
finalinherited
stdoutReadyFunction → OutputReadyFunction?
finalinherited
version → String?
finalinherited
volumes → Map<String, String>?
finalinherited

Methods

copy({String? image, String? version, List<String>? imageArgs, String? name, String? network, String? hostname, List<String>? ports, List<int>? hostPorts, List<int>? containerPorts, Map<String, String>? environment, Map<String, String>? volumes, bool? cleanContainer, int? outputLimit, bool? outputAsLines, OutputReadyFunction? stdoutReadyFunction, OutputReadyFunction? stderrReadyFunction}) → DockerContainerConfig<DockerContainer>
inherited
initializeContainer(MySQLContainer dockerContainer) → Future<bool>
override
instantiateDockerContainer(DockerRunner runner) → MySQLContainer?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(DockerCommander dockerCommander, {String? name, String? network, String? hostname, List<int>? hostPorts, bool cleanContainer = true, int? outputLimit}) → Future<MySQLContainer>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited