OutputStream<T> class

Handles the output stream of a Docker container.

Constructors

OutputStream(OutputStreamType type, Encoding _encoding, bool stringData, int limit, OutputReadyFunction outputReadyFunction, Completer<bool> anyOutputReadyCompleter)

Properties

anyOutputReadyCompleter → Completer<bool>
final
asBytes → List<int>
Converts and returns _data entries as bytes.
no setter
asLines → List<String>
Converts and returns _data entries as lines List<String>.
no setter
asString → String
Converts and returns _data entries as String.
no setter
bufferedContentSize → int
Returns the size of the buffered content.
no setter
contentRemoved → int
Size of removed content, due _limit.
no setter
data → UnmodifiableListView<T>
The output data List.
no setter
dataAsBytes → UnmodifiableListView<int>
Returns data as bytes.
no setter
dataAsListOfStrings → UnmodifiableListView<String>
Returns data as a List of String.
no setter
entriesLength → int
Current length of _data buffer.
no setter
entriesRemoved → int
Number of removed entries, due _limit.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isDisposed → bool
no setter
isReady → bool
no setter
limit ↔ int
The limit of entries.
getter/setter pair
onData → EventStream
On data event listener.
final
onDispose ↔ EventStream<OutputStream<T>>
getter/setter pair
outputReadyFunction → OutputReadyFunction
The functions that determines if this output is ready. Called for each output entry.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringData → bool
final
type → OutputStreamType
final

Methods

add(T entry) → void
Adds an entry to the _data buffer.
addAll(Iterable<T> entries) → void
Adds all entries to the _data buffer.
addLines(String data) → void
asStringFrom({int? entriesRealOffset, int? contentRealOffset}) → String
Same as asString, but resolves entriesRealOffset and contentRealOffset.
dispose() → void
getEntries({int? offset, int? realOffset}) → List<T>
Returns a List of entries, from offset or realOffset.
markReady() → void
Mars this output as ready.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
waitAnyOutputReady() → Future<bool>
waitData({Duration? timeout}) → Future<bool>
Waits with a timeout for new data.
waitForDataMatch(Pattern dataMatcher, {Duration? timeout}) → Future<bool>
Waits for dataMatcher with a timeout.
waitReady() → Future<bool>

Operators

operator ==(Object other) → bool
The equality operator.
inherited