OutputSync class

Constructors

OutputSync(int? length, int? removed, List? entries, int? exitCode)
OutputSync.notRunning()

Properties

entries → List?
final
exitCode → int?
final
hashCode → int
The hash code for this object.
no setterinherited
length → int?
final
removed → int?
final
running → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited