AuthenticationTable class

A basic table of username and password.

Constructors

AuthenticationTable(Map<String, String> usernamesAndPasswords)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usernamesAndPasswords → Map<String, String>
final

Methods

checkPassword(String username, String password) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited