ContainerInfosLocal class

Inheritance

Constructors

ContainerInfosLocal(String containerName, String? image, File? idFile, List<String>? ports, String? containerNetwork, String? containerHostname, List<String>? args)

Properties

args ↔ List<String>?
getter/setter pairinherited
containerHostname → String?
finalinherited
containerName → String
finalinherited
containerNetwork → String?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pairinherited
idFile → File?
final
image → String?
finalinherited
ports → List<String>?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited