DockerHostServer class

A DockerHost Server, to be used by DockerHostRemote.

Constructors

DockerHostServer(AuthenticationGrantor _authenticationGrantor, int listenPort, {bool public = false, bool ipv6 = false, Duration? authenticationTokenTimeout})

Properties

authenticationTokenTimeout → Duration
The authentication token timeout.
final
hashCode → int
The hash code for this object.
no setterinherited
ipv6 → bool
If true will use IPv6.
final
isStarted → bool
no setter
listenPort → int
The HttpServer port.
final
public → bool
If true will accept connections from any hostname.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkAuthentication(HttpRequest request, Map<String, String> parameters) → Future<Authentication>
checkAuthenticationBasicSecurity() → Future<bool>
checkPassword(String? username, String? password) → Future<bool>
close() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setResponseHeader(HttpRequest request, String key, String value) → void
start() → Future<void>
startAndWait() → Future<void>
toString() → String
A string representation of this object.
override
validateToken(String token) → bool
waitStart() → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

weakPasswords → const Set<String>
weakUsernames → const Set<String>