DockerProcessLocal class

Inheritance
Implementers

Constructors

DockerProcessLocal(DockerHostLocal dockerHost, int instanceID, String containerName, Process process, bool? outputAsLines, int? _outputLimit, OutputReadyFunction _stdoutReadyFunction, OutputReadyFunction _stderrReadyFunction, OutputReadyType _outputReadyType)

Properties

containerName → String
The name of the associated container.
finalinherited
dockerHost → DockerHostLocal
DockerHost where this container is running.
no setteroverride
exitCode → int?
The exist code, returned by waitExit, or null if still running.
no setteroverride
exitElapsedTime → Duration?
If exitCode is defined, returns the elapsed time from exitTime.
no setterinherited
exitTime → DateTime?
Returns the time of exit. Computed when exitCode is set.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
instanceID → int
The internal instanceID in DockerCommander.
finalinherited
isFinished → bool
Returns true if exitCode is defined (process exited).
no setterinherited
isReady → bool
Returns true if this container is started and ready.
no setteroverride
isRunning → bool
Returns true if this containers is running.
no setteroverride
outputAsLines → bool?
final
outputReadyType → OutputReadyType?
The ready output behavior.
no setterinherited
process → Process
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stderr → Output?
The STDERR of this container.
no setterinherited
stdout → Output?
The STDOUT of this container.
no setterinherited

Methods

dispose() → void
inherited
initialize() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setupOutputReadyType(OutputReadyType outputReadyType) → void
inherited
setupStderr(OutputStream outputStream) → void
inherited
setupStdout(OutputStream outputStream) → void
inherited
toString() → String
A string representation of this object.
inherited
waitExit({int? desiredExitCode, Duration? timeout}) → Future<int?>
Waits this container to naturally exit.
override
waitExitAndConfirm(int desiredExitCode) → Future<bool>
Waits this container to naturally exit.
inherited
waitReady() → Future<bool>
Waits this container to start and be ready.
override
waitStderr({int? desiredExitCode}) → Future<Output?>
Calls waitExit and returns stderr
inherited
waitStdout({int? desiredExitCode}) → Future<Output?>
Calls waitExit and returns stdout
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited