DockerRunnerLocal class

Inheritance
Implemented types

Constructors

DockerRunnerLocal(DockerHostLocal dockerHost, int instanceID, String containerName, String? image, Process process, File? idFile, List<String>? _ports, String? network, String? hostname, bool outputAsLines, int? outputLimit, OutputReadyFunction stdoutReadyFunction, OutputReadyFunction stderrReadyFunction, OutputReadyType outputReadyType)

Properties

containerName → String
The name of the associated container.
finalinherited
dockerHost → DockerHostLocal
DockerHost where this container is running.
no setterinherited
exitCode → int?
The exist code, returned by waitExit, or null if still running.
no setterinherited
exitElapsedTime → Duration?
If exitCode is defined, returns the elapsed time from exitTime.
no setterinherited
exitTime → DateTime?
Returns the time of exit. Computed when exitCode is set.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hostname → String?
final
id → String?
The ID of this container.
no setteroverride
idFile → File?
An optional File that contains the container ID.
final
image → String?
The image:version of this container.
final
instanceID → int
The internal instanceID in DockerCommander.
finalinherited
ip → String?
no setter
isFinished → bool
Returns true if exitCode is defined (process exited).
no setterinherited
isReady → bool
Returns true if this container is started and ready.
no setterinherited
isRunning → bool
Returns true if this containers is running.
no setterinherited
network → String?
final
outputAsLines → bool?
finalinherited
outputReadyType → OutputReadyType?
The ready output behavior.
no setterinherited
ports → List<String>
Returns the mapped ports.
no setteroverride
process → Process
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stderr → Output?
The STDERR of this container.
no setterinherited
stdout → Output?
The STDOUT of this container.
no setterinherited

Methods

dispose() → void
inherited
initialize() → Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setupOutputReadyType(OutputReadyType outputReadyType) → void
inherited
setupStderr(OutputStream outputStream) → void
inherited
setupStdout(OutputStream outputStream) → void
inherited
stop({Duration? timeout}) → Future<bool>
Stops this container.
override
toString() → String
A string representation of this object.
override
waitExit({int? desiredExitCode, Duration? timeout}) → Future<int?>
Waits this container to naturally exit.
inherited
waitExitAndConfirm(int desiredExitCode) → Future<bool>
Waits this container to naturally exit.
inherited
waitReady() → Future<bool>
Waits this container to start and be ready.
inherited
waitStderr({int? desiredExitCode}) → Future<Output?>
Calls waitExit and returns stderr
inherited
waitStdout({int? desiredExitCode}) → Future<Output?>
Calls waitExit and returns stdout
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited