isReused property
Returns true if this runner attached to a container that was
already running (see DockerRunOptions.reuse).
Implementation
@override
final bool isReused;
Returns true if this runner attached to a container that was
already running (see DockerRunOptions.reuse).
@override
final bool isReused;